@@ -12,6 +12,12 @@
 #include <float.h>
 #define GLIB_HAVE_SYS_POLL_H
 
+/* Specifies that GLib's g_print*() functions wrap the
+ * system printf functions.  This is useful to know, for example,
+ * when using glibc's register_printf_function().
+ */
+#define GLIB_USING_SYSTEM_PRINTF
+
 G_BEGIN_DECLS
 
 #define G_MINFLOAT	FLT_MIN
@@ -76,6 +82,9 @@ typedef gint64 goffset;
 #define GINT_TO_POINTER(i)	((gpointer) (glong) (i))
 #define GUINT_TO_POINTER(u)	((gpointer) (gulong) (u))
 
+typedef signed long gintptr;
+typedef unsigned long guintptr;
+
 #ifdef NeXT /* @#%@! NeXTStep */
 # define g_ATEXIT(proc)	(!atexit (proc))
 #else
@@ -85,12 +94,14 @@ typedef gint64 goffset;
 #define g_memmove(dest,src,len) G_STMT_START { memmove ((dest), (src), (len)); } G_STMT_END
 
 #define GLIB_MAJOR_VERSION 2
-#define GLIB_MINOR_VERSION 16
+#define GLIB_MINOR_VERSION 18
 #define GLIB_MICRO_VERSION 4
 
 #define G_OS_UNIX
 
+
 #define G_VA_COPY	va_copy
+#define G_VA_COPY_AS_ARRAY 1
 
 #ifdef	__cplusplus
 #define	G_HAVE_INLINE	1
@@ -125,7 +136,9 @@ typedef gint64 goffset;
 #define G_HAVE_GROWING_STACK 0
 
 #define G_HAVE_GNUC_VISIBILITY 1
-#if defined(__SUNPRO_C) && (__SUNPRO_C >= 0x550)
+#if defined(__SUNPRO_C) && (__SUNPRO_C >= 0x590)
+#define G_GNUC_INTERNAL __attribute__((visibility("hidden")))
+#elif defined(__SUNPRO_C) && (__SUNPRO_C >= 0x550)
 #define G_GNUC_INTERNAL __hidden
 #elif defined (__GNUC__) && defined (G_HAVE_GNUC_VISIBILITY)
 #define G_GNUC_INTERNAL __attribute__((visibility("hidden")))
@@ -163,8 +176,6 @@ union _GSystemThread
   long   dummy_long;
 };
 
-#define G_ATOMIC_OP_MEMORY_BARRIER_NEEDED 1
-
 #define GINT16_TO_LE(val)	((gint16) (val))
 #define GUINT16_TO_LE(val)	((guint16) (val))
 #define GINT16_TO_BE(val)	((gint16) GUINT16_SWAP_LE_BE (val))
@@ -196,6 +207,13 @@ union _GSystemThread
 
 #define G_MODULE_SUFFIX "so"
 
+/* A GPid is an abstraction for a process "handle". It is *not* an
+ * abstraction for a process identifier in general. GPid is used in
+ * GLib only for descendant processes spawned with the g_spawn*
+ * functions. On POSIX there is no "process handle" concept as such,
+ * but on Windows a GPid is a handle to a process, a kind of pointer,
+ * not a process identifier.
+ */
 typedef int GPid;
 
 G_END_DECLS
